import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Events::Endpoint.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const sampleEndpoint = new aws_native.events.Endpoint("sampleEndpoint", {
 *     name: "CreateExampleEndpoint",
 *     routingConfig: {
 *         failoverConfig: {
 *             primary: {
 *                 healthCheck: "arn:aws:route53:::healthcheck/0123456789abc",
 *             },
 *             secondary: {
 *                 route: "us-east-1",
 *             },
 *         },
 *     },
 *     replicationConfig: {
 *         state: aws_native.events.EndpointReplicationState.Enabled,
 *     },
 *     roleArn: "arn:aws:iam::123456789012:role/EndpointReplicationRole",
 *     eventBuses: [
 *         {
 *             eventBusArn: "arn:aws:events:us-west-2:123456789012:event-bus/ExampleEventBus",
 *         },
 *         {
 *             eventBusArn: "arn:aws:events:us-east-1:123456789012:event-bus/ExampleEventBus",
 *         },
 *     ],
 * });
 * export const sampleEndpointName = sampleEndpoint.id;
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const sampleEndpoint = new aws_native.events.Endpoint("sampleEndpoint", {
 *     name: "CreateExampleEndpoint",
 *     routingConfig: {
 *         failoverConfig: {
 *             primary: {
 *                 healthCheck: "arn:aws:route53:::healthcheck/0123456789abc",
 *             },
 *             secondary: {
 *                 route: "us-east-1",
 *             },
 *         },
 *     },
 *     replicationConfig: {
 *         state: aws_native.events.EndpointReplicationState.Disabled,
 *     },
 *     eventBuses: [
 *         {
 *             eventBusArn: "arn:aws:events:us-west-2:123456789012:event-bus/ExampleEventBus",
 *         },
 *         {
 *             eventBusArn: "arn:aws:events:us-east-1:123456789012:event-bus/ExampleEventBus",
 *         },
 *     ],
 * });
 * export const sampleEndpointName = sampleEndpoint.id;
 *
 * ```
 */
export declare class Endpoint extends pulumi.CustomResource {
    /**
     * Get an existing Endpoint resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Endpoint;
    /**
     * Returns true if the given object is an instance of Endpoint.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Endpoint;
    /**
     * The ARN of the endpoint.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A description for the endpoint.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ID of the endpoint.
     */
    readonly endpointId: pulumi.Output<string>;
    /**
     * The URL of the endpoint.
     */
    readonly endpointUrl: pulumi.Output<string>;
    /**
     * The event buses being used by the endpoint.
     *
     * *Exactly* : `2`
     */
    readonly eventBuses: pulumi.Output<outputs.events.EndpointEventBus[]>;
    /**
     * The name of the endpoint.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * Whether event replication was enabled or disabled for this endpoint. The default state is `ENABLED` which means you must supply a `RoleArn` . If you don't have a `RoleArn` or you don't want event replication enabled, set the state to `DISABLED` .
     */
    readonly replicationConfig: pulumi.Output<outputs.events.EndpointReplicationConfig | undefined>;
    /**
     * The ARN of the role used by event replication for the endpoint.
     */
    readonly roleArn: pulumi.Output<string | undefined>;
    /**
     * The routing configuration of the endpoint.
     */
    readonly routingConfig: pulumi.Output<outputs.events.EndpointRoutingConfig>;
    /**
     * The main Region of the endpoint.
     */
    readonly state: pulumi.Output<enums.events.EndpointState>;
    /**
     * The reason the endpoint is in its current state.
     */
    readonly stateReason: pulumi.Output<string>;
    /**
     * Create a Endpoint resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EndpointArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Endpoint resource.
 */
export interface EndpointArgs {
    /**
     * A description for the endpoint.
     */
    description?: pulumi.Input<string>;
    /**
     * The event buses being used by the endpoint.
     *
     * *Exactly* : `2`
     */
    eventBuses: pulumi.Input<pulumi.Input<inputs.events.EndpointEventBusArgs>[]>;
    /**
     * The name of the endpoint.
     */
    name?: pulumi.Input<string>;
    /**
     * Whether event replication was enabled or disabled for this endpoint. The default state is `ENABLED` which means you must supply a `RoleArn` . If you don't have a `RoleArn` or you don't want event replication enabled, set the state to `DISABLED` .
     */
    replicationConfig?: pulumi.Input<inputs.events.EndpointReplicationConfigArgs>;
    /**
     * The ARN of the role used by event replication for the endpoint.
     */
    roleArn?: pulumi.Input<string>;
    /**
     * The routing configuration of the endpoint.
     */
    routingConfig: pulumi.Input<inputs.events.EndpointRoutingConfigArgs>;
}
